==> recime-bot-extension-4.4.0.tgz: package/src/ext/telegram.ts <==
/*jshint esversion: 6 */

import { Channel, QuickReplyButton } from "./channel";

export interface KeyBoardButton {
  request_contact?: Boolean;
  request_location?: Boolean;
}

export class TGExtension extends Channel {
  text(text: String, quickReplies?: QuickReplyButton[]) {
    const template: any = {
      type: "message",
      payload: {
        text: text,
        parse_mode: "Markdown"
      }
    };

    this.appInlineKeyboard(template, quickReplies);

    return template;
  }

  image(url, quickReplies?: QuickReplyButton[], assetId?: string) {
    const template = {
      type: "photo",
      payload: {
        photo: url
      }
    };

    this.appInlineKeyboard(template, quickReplies);

    return template;
  }

  genericTemplate(templates) {
    return templates.reduce((a, b) => {
      return a.concat(b);
    });
  }

  genericItem(title, subtitle, imageUrl, actionUrl, buttons, assetId) {
    let body = [];

    body.push(this.text(title));

    if (subtitle) body.push(this.text(subtitle));

    if (actionUrl) body.push(this.url(actionUrl));

    if (imageUrl) body.push(this.image(imageUrl, buttons));

    return body;
  }

  quickReplyButtonTemplate(text: String, buttons: any) {
    var template = {
      type: "message",
      payload: {
        text: text,
        reply_markup: {
          keyboard: [],
          resize_keyboard: true
        }
      }
    };
    // verticle.
    for (var button of buttons)
      template.payload.reply_markup.keyboard.push([button]);

    return template;
  }

  // facebook compatibilty
  quickReplyButton(title: String, payload: any, options: KeyBoardButton) {
    return {
      text: title,
      request_contact:
        (payload && payload.request_contact) ||
        (options && options.request_contact),
      request_location:
        (payload && payload.request_location) ||
        (options && options.request_location)
    };
  }

  postbackButton(title: String, payload: any) {
    return {
      text: title
    };
  }

  buttonTemplate(text: String, quickReplies?: QuickReplyButton[]) {
    const template: any = {
      type: "message",
      payload: {
        text: text,
        parse_mode: "Markdown"
      }
    };

    this.appendKeyboard(template, quickReplies);

    return template;
  }

  url(url) {
    return this.text(`[${url}](${url})`);
  }

  typing(){
    return this.text("typing...");
  }

  private appendKeyboard(template, quickReplies: any) {
    if (quickReplies) {
      template.payload.reply_markup = {
        keyboard: [],
        resize_keyboard: true
      };

      for (var button of quickReplies) {
        template.payload.reply_markup.keyboard.push([
          {
            text: `/${button.title}`,
            request_contact : button.request_contact,
            request_location: button.request_location
          }
        ]);
      }
    }
  }

  private appInlineKeyboard(template, quickReplies: any) {
    if (quickReplies) {
      template.payload.reply_markup = {
        inline_keyboard: []
      };

      for (var button of quickReplies) {
        template.payload.reply_markup.inline_keyboard.push([
          {
            text: button.title,
            callback_data: button.payload,
            url: button.url
          }
        ]);
      }
    }
  }
}

==> recime-bot-extension-4.4.3.tgz: package/src/ext/telegram.ts <==
/*jshint esversion: 6 */

import { Channel, QuickReplyButton } from "./channel";

export interface KeyBoardButton {
  request_contact?: Boolean;
  request_location?: Boolean;
}

export class TGExtension extends Channel {
  text(text: String, quickReplies?: QuickReplyButton[]) {
    const template: any = {
      type: "message",
      payload: {
        text: text,
        parse_mode: "Markdown"
      }
    };

    this.appInlineKeyboard(template, quickReplies);

    return template;
  }

  image(url, quickReplies?: QuickReplyButton[], assetId?: string) {
    const template = {
      type: "photo",
      payload: {
        photo: url
      }
    };

    this.appInlineKeyboard(template, quickReplies);

    return template;
  }

  genericTemplate(templates) {
    return templates.reduce((a, b) => {
      return a.concat(b);
    });
  }

  genericItem(title, subtitle, imageUrl, actionUrl, buttons, assetId) {
    let body = [];

    body.push(this.text(title));

    if (subtitle) body.push(this.text(subtitle));

    if (actionUrl) body.push(this.url(actionUrl));

    if (imageUrl) body.push(this.image(imageUrl, buttons));

    return body;
  }

  quickReplyButtonTemplate(text: String, buttons: any) {
    var template = {
      type: "message",
      payload: {
        text: text,
        reply_markup: {
          keyboard: [],
          resize_keyboard: true
        }
      }
    };
    // verticle.
    for (var button of buttons)
      template.payload.reply_markup.keyboard.push([button]);

    return template;
  }

  // facebook compatibilty
  quickReplyButton(title: String, payload: any, options: KeyBoardButton) {
    return {
      text: title,
      request_contact:
        (payload && payload.request_contact) ||
        (options && options.request_contact),
      request_location:
        (payload && payload.request_location) ||
        (options && options.request_location)
    };
  }

  postbackButton(title: String, payload: any) {
    return {
      text: title
    };
  }

  buttonTemplate(text: String, quickReplies?: QuickReplyButton[]) {
    const template: any = {
      type: "message",
      payload: {
        text: text,
        parse_mode: "Markdown"
      }
    };

    this.appendKeyboard(template, quickReplies);

    return template;
  }

  url(url) {
    return this.text(`[${url}](${url})`);
  }

  typing(){
    return this.text("...");
  }

  replyButton(title: String, payload: any) {
    return this.postbackButton(title, `reply-${payload}`)
  }

  private appendKeyboard(template, quickReplies: any) {
    if (quickReplies) {
      template.payload.reply_markup = {
        keyboard: [],
        resize_keyboard: true
      };

      for (var button of quickReplies) {
        template.payload.reply_markup.keyboard.push([
          {
            text: `/${button.title}`,
            request_contact : button.request_contact,
            request_location: button.request_location
          }
        ]);
      }
    }
  }

  private appInlineKeyboard(template, quickReplies: any) {
    if (quickReplies) {
      template.payload.reply_markup = {
        inline_keyboard: []
      };

      for (var button of quickReplies) {
        template.payload.reply_markup.inline_keyboard.push([
          {
            text: button.title,
            callback_data: button.payload,
            url: button.url
          }
        ]);
      }
    }
  }
}
